@@ -15,15 +15,13 @@ impl<M> Pure<'_, M>
 where
     M: Mode,
 {
-    pub(super) fn negate_twice(&mut self, e: &mut Expr) {
-        self.changed = true;
-        negate(e, false);
-        negate(e, false);
+    pub(super) fn negate_twice(&mut self, e: &mut Expr, is_ret_val_ignored: bool) {
+        self.changed |= negate(e, false, is_ret_val_ignored);
+        self.changed |= negate(e, false, is_ret_val_ignored);
     }
 
-    pub(super) fn negate(&mut self, e: &mut Expr, in_bool_ctx: bool) {
-        self.changed = true;
-        negate(e, in_bool_ctx)
+    pub(super) fn negate(&mut self, e: &mut Expr, in_bool_ctx: bool, is_ret_val_ignored: bool) {
+        self.changed |= negate(e, in_bool_ctx, is_ret_val_ignored)
     }
 
     /// `!(a && b)` => `!a || !b`
@@ -53,7 +51,7 @@ where
                     }
                     tracing::debug!("bools: Optimizing `!(a && b)` as `!a || !b`");
                     self.changed = true;
-                    self.negate(arg, false);
+                    self.negate(arg, false, false);
                     *e = *arg.take();
 
                     return;
@@ -76,7 +74,7 @@ where
                             return;
                         }
                         tracing::debug!("bools: Optimizing `!!(a || b)` as `!a && !b`");
-                        self.negate(arg_of_arg, false);
+                        self.negate(arg_of_arg, false, false);
                         *e = *arg.take();
 
                         return;
@@ -296,7 +294,7 @@ where
                             let last = exprs.last_mut().unwrap();
                             self.optimize_expr_in_bool_ctx(last);
                             // Negate last element.
-                            negate(last, false);
+                            self.changed |= negate(last, false, false);
                         }
 
                         *n = *e.arg.take();
@@ -541,7 +539,7 @@ where
         }
 
         if self.can_swap_bin_operands(&left, &right, false) {
-            tracing::debug!("Swapping operands of binary exprssion");
+            tracing::debug!("Swapping operands of binary expession");
             swap(left, right);
             return true;
         }
